@@ -13,6 +13,7 @@ import (
 	"reflect"
 	"regexp"
 	"runtime"
+	"strconv"
 	"strings"
 	"testing"
 	"time"
@@ -177,6 +178,8 @@ var writeCommentTests = []struct {
 	{"# comment\n\nkey = value", "# comment\nkey = value\n", "ISO-8859-1"},
 	{"# comment1\n# comment2\nkey = value", "# comment1\n# comment2\nkey = value\n", "ISO-8859-1"},
 	{"#comment1\nkey1 = value1\n#comment2\nkey2 = value2", "# comment1\nkey1 = value1\n\n# comment2\nkey2 = value2\n", "ISO-8859-1"},
+	// prevent double encoding \\ -> \\\\ -> \\\\\\\\
+	{"# com\\\\ment\nkey = value", "# com\\\\ment\nkey = value\n", "ISO-8859-1"},
 
 	// UTF-8 tests
 	{"key = value", "key = value\n", "UTF-8"},
@@ -185,6 +188,8 @@ var writeCommentTests = []struct {
 	{"# comment⌘\n\nkey = value⌘", "# comment⌘\nkey = value⌘\n", "UTF-8"},
 	{"# comment1⌘\n# comment2⌘\nkey = value⌘", "# comment1⌘\n# comment2⌘\nkey = value⌘\n", "UTF-8"},
 	{"#comment1⌘\nkey1 = value1⌘\n#comment2⌘\nkey2 = value2⌘", "# comment1⌘\nkey1 = value1⌘\n\n# comment2⌘\nkey2 = value2⌘\n", "UTF-8"},
+	// prevent double encoding \\ -> \\\\ -> \\\\\\\\
+	{"# com\\\\ment⌘\nkey = value⌘", "# com\\\\ment⌘\nkey = value⌘\n", "UTF-8"},
 }
 
 // ----------------------------------------------------------------------------
@@ -559,15 +564,23 @@ func TestMustGetParsedDuration(t *testing.T) {
 	p := mustParse(t, input)
 	assert.Equal(t, p.MustGetParsedDuration("key"), 123*time.Millisecond)
 
-	ver := runtime.Version()
-	switch {
-	// gotip and go1.15 will return `time: invalid duration "ghi"`
-	case !strings.HasPrefix(ver, "go") || strings.HasPrefix(ver, "go1.15"):
-		assert.Panic(t, func() { p.MustGetParsedDuration("key2") }, `time: invalid duration "ghi"`)
-	default:
-		assert.Panic(t, func() { p.MustGetParsedDuration("key2") }, `time: invalid duration ghi`)
+	// parse runtime.Version into major and minor version
+	var major, minor int
+	ver := strings.Split(runtime.Version(), ".")
+	devel := !strings.HasPrefix(ver[0], "go")
+	major, _ = strconv.Atoi(strings.TrimPrefix(ver[0], "go"))
+	if len(ver) > 1 {
+		minor, _ = strconv.Atoi(ver[1])
 	}
 
+	switch {
+	case devel || major == 1 && minor >= 15:
+		// go1.15 ... gotip
+		assert.Panic(t, func() { p.MustGetParsedDuration("key2") }, `time: invalid duration "ghi"`)
+	default:
+		// go1.x..go1.14
+		assert.Panic(t, func() { p.MustGetParsedDuration("key2") }, `time: invalid duration ghi`)
+	}
 	assert.Panic(t, func() { p.MustGetParsedDuration("invalid") }, "unknown property: invalid")
 }
 
